### Documentation

   - Add `User` to the documentation ([2539f70e0ffc292ed57bf14e2f2c134f3fad234a](https://github.com/hearot/pyrubrum/commit/2539f70e0ffc292ed57bf14e2f2c134f3fad234a))
   - Add a features list ([e0155add9888f3efc6b2113701f512265c54b4ac](https://github.com/hearot/pyrubrum/commit/e0155add9888f3efc6b2113701f512265c54b4ac))
   - Add docstrings to `User` ([9e7c1e6cb545fafef724eeebb3fc8589aa6eca7c](https://github.com/hearot/pyrubrum/commit/9e7c1e6cb545fafef724eeebb3fc8589aa6eca7c))

### Fixes

   - Create `_static/examples` directory ([13c734b3fef563821e39993100c06f32e49f1aef](https://github.com/hearot/pyrubrum/commit/13c734b3fef563821e39993100c06f32e49f1aef))
   - Dependabot now uses just "chore" as prefix
   - Do not raise `UnboundLocalError` anymore ([ce46b4f4a094cede204f01275fa9973b4a90e0cc](https://github.com/hearot/pyrubrum/commit/ce46b4f4a094cede204f01275fa9973b4a90e0cc))
   - Keep backwards compatibility for `sphinx` ([f6a5e9c3163c619abe5dc199545879bd4d0ddccf](https://github.com/hearot/pyrubrum/commit/f6a5e9c3163c619abe5dc199545879bd4d0ddccf))
   - Set `master_doc` to `index` ([0042b2e78e1e9f4b299fb81eb8eb167e4b8287d4](https://github.com/hearot/pyrubrum/commit/0042b2e78e1e9f4b299fb81eb8eb167e4b8287d4))
   - The changelog generator now supports URLs ending in .git ([0506f07bc0a2d86ac095173fa5661d772c271179](https://github.com/hearot/pyrubrum/commit/0506f07bc0a2d86ac095173fa5661d772c271179))

### New features

   - Add `User` ([17c92f73dd7409729acad316bd8b819ef0cb5e95](https://github.com/hearot/pyrubrum/commit/17c92f73dd7409729acad316bd8b819ef0cb5e95))

### Other changes

   - Update (deps): bump sphinx from 3.1.1 to 3.1.2 ([fc9a1a125c40f25439b916f65d41fe4fbd4fc1df](https://github.com/hearot/pyrubrum/commit/fc9a1a125c40f25439b916f65d41fe4fbd4fc1df))

### ‼️ Breaking changes

   - Update to Pyrogram 1.0 ([937164ce11a2d7e85e8e2e7551dffe3c10194dd8](https://github.com/hearot/pyrubrum/commit/937164ce11a2d7e85e8e2e7551dffe3c10194dd8))
